@@ -25,7 +25,7 @@ import os.path
 import re
 import yaml
 from ..cases import hash_from_fields as _hash_from_fields
-from ..exceptions import DataParseError
+from ..exceptions import DataParseError, MultipleAugmentationEntriesError
 from ..json_asn1.convert import asn1_der
 from ..utils import def_enum
 from ..yaml_tools import (
@@ -34,6 +34,7 @@ from ..yaml_tools import (
     value_from_event_stream as _value_from_events,
     get_load_fn as _get_yaml_loader,
 )
+from . import origin_mapping_stream as oms
 
 class Indexer:
     """Builds an index of the augmentation data in a working/update file
@@ -70,7 +71,7 @@ class Indexer:
         self._index = {}
         self._anchors = {}
     
-    def read(self, event):
+    def read(self, event, origin_mapper: oms.OriginMapper):
         self._event = event
         anchor = getattr(event, 'anchor', None)
         if anchor is not None:
@@ -78,8 +79,14 @@ class Indexer:
                 if getattr(self, '_case_data_start', 0) > self._anchors.get(event.anchor, math.inf):
                     self._case_atomic = False
             else:
-                self._anchors[anchor] = event.start_mark.index
-        return getattr(self, '_read_from_' + self._state.name)(event)
+                self._anchors[anchor] = origin_mapper.tell_of_chr(
+                    event.start_mark.index
+                )
+        try:
+            self.omapper = origin_mapper
+            return getattr(self, '_read_from_' + self._state.name)(event)
+        finally:
+            del self.omapper
     
     def _read_from_header(self, event):
         if not isinstance(event, yaml.NodeEvent):
@@ -95,7 +102,9 @@ class Indexer:
             self._case_data_start = None
         else:
             # Record the offset into the file of the start of the first line of this data case
-            self._case_data_start = event.start_mark.index - event.start_mark.column
+            self._case_data_start = self.omapper.tell_of_chr(
+                event.start_mark.index - event.start_mark.column
+            )
             
             self._expect(yaml.MappingStartEvent)
             self._state = self.State.case_mapping
@@ -190,9 +199,9 @@ def index(paths, key_fields, *, safe_loading=True):
     indexer = Indexer(key_fields, safe_loading=safe_loading)
     for path in paths:
         case_index = itertools.count(0)
-        with open(path) as instream:
+        with oms.open(path) as instream:
             for event in yaml.parse(instream):
-                entry = indexer.read(event)
+                entry = indexer.read(event, instream.origin_mapper)
                 if entry is not None:
                     case_key, offset = entry
                     new_augmenter = TestCaseAugmenter(path, offset, key_fields, case_index=next(case_index), safe_loading=safe_loading)
@@ -302,7 +311,7 @@ class TestCaseAugmenter:
         self.case_index = case_index
     
     def __call__(self, d):
-        with open(self.file_path) as stream:
+        with open(self.file_path, 'rb') as stream:
             if self.offset is None:
                 for k, v in self._load_yaml(stream)[self.case_index].items():
                     d.setdefault(k, v)
@@ -321,7 +330,7 @@ class TestCaseAugmenter:
         return self.file_path.rsplit('.', 2)[0] + YAML_EXT
     
     def case_data_events(self, ):
-        with open(self.file_path) as stream:
+        with open(self.file_path, 'rb') as stream:
             if self.offset is None:
                 augmentation_data = self._load_yaml(stream)[self.case_index]
                 for k in self.key_fields:
