@@ -178,9 +178,12 @@ class InterfaceCaseProvider:
         * Each returned runner callable will log the test case as YAML prior
           to invoking *fn*, which is helpful when updating the augmenting data
           for the case becomes necessary
+        
+        Each callable generated will also have the case data available via
+        an :attr:`case` on the callable.
         """
         
-        if do_compact_updates:
+        if do_compact_updates and self._case_augmenter is not None:
             fn = self.update_compact_augmentation_on_success(fn)
         
         for case in self.cases():
@@ -192,6 +195,8 @@ class InterfaceCaseProvider:
                 ))
                 return fn(*args, case, **kwargs)
             
+            wrapper.case = case
+            
             yield wrapper
     
     def update_compact_files(self, ):
@@ -208,11 +213,11 @@ class InterfaceCaseProvider:
     def merge_test_extensions(self, ):
         """Merge the extension files of the target group into the group's main file"""
         ext_files = sorted(self.extension_files())
-        with open(self.main_group_test_file, 'a') as fixed_version_specs:
+        with open(self.main_group_test_file, 'ab') as fixed_version_specs:
             for ext_file in ext_files:
                 ext_file_ref = os.path.relpath(ext_file, os.path.join(self.spec_dir, self.group_name))
-                print("---\n# From {}\n".format(ext_file_ref), file=fixed_version_specs)
-                with open(ext_file) as ext_specs:
+                print("---\n# From {}\n".format(ext_file_ref).encode('utf8'), file=fixed_version_specs)
+                with open(ext_file, 'rb') as ext_specs:
                     shutil.copyfileobj(ext_specs, fixed_version_specs)
         
         for ext_file in ext_files:
@@ -223,7 +228,7 @@ class InterfaceCaseProvider:
         return x
     
     def _cases_from_file(self, filepath):
-        with open(filepath) as file:
+        with open(filepath, 'rb') as file:
             load_all_yaml = _get_yaml_load_all(safe=self.safe_yaml_loading)
             for test_case in (
                 tc
@@ -430,7 +435,7 @@ class CaseAugmenter:
         """Update compact data files from update data files"""
         for file_path, updates in self._updates.items():
             if os.path.exists(file_path):
-                with open_temp_copy(file_path) as instream, open(file_path, 'w') as outstream:
+                with open_temp_copy(file_path, binary=True) as instream, open(file_path, 'wb') as outstream:
                     updated_events = self._updated_compact_events(
                         yaml.parse(instream),
                         updates
@@ -438,7 +443,7 @@ class CaseAugmenter:
                     
                     yaml.emit(updated_events, outstream)
             else:
-                with open(file_path, 'w') as outstream:
+                with open(file_path, 'wb') as outstream:
                     yaml.emit(self._fresh_content_events(updates.items()), outstream)
     
     def extend_updates(self, file_name_base):
@@ -563,7 +568,7 @@ class UpdateExtender:
                 self._case_augmenter.augmented_test_case_events(*test_case)
             )
             # Append augmentation case to self.file_name
-            with open(self.file_name, 'a') as outstream:
+            with open(self.file_name, 'ab') as outstream:
                 yaml.emit(
                     self._case_yaml_events(case_as_currently_augmented_events),
                     outstream,
